/****************************************************************************
** Meta object code from reading C++ file 'abstractselectioncontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../akregator-26.08.0/src/abstractselectioncontroller.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractselectioncontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Akregator27AbstractSelectionControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto Akregator::AbstractSelectionController::qt_create_metaobjectdata<qt_meta_tag_ZN9Akregator27AbstractSelectionControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akregator::AbstractSelectionController",
        "currentSubscriptionChanged",
        "",
        "Akregator::TreeNode*",
        "node",
        "currentArticleChanged",
        "Akregator::Article",
        "articleDoubleClicked",
        "settingsChanged",
        "activitiesChanged",
        "setFilters",
        "std::vector<QSharedPointer<const Akregator::Filters::AbstractMatch"
        "er>>",
        "forceFilterUpdate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentSubscriptionChanged'
        QtMocHelpers::SignalData<void(Akregator::TreeNode *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'currentArticleChanged'
        QtMocHelpers::SignalData<void(const Akregator::Article &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'articleDoubleClicked'
        QtMocHelpers::SignalData<void(const Akregator::Article &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'settingsChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activitiesChanged'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFilters'
        QtMocHelpers::SlotData<void(const std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher>> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'forceFilterUpdate'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractSelectionController, qt_meta_tag_ZN9Akregator27AbstractSelectionControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akregator::AbstractSelectionController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Akregator27AbstractSelectionControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Akregator27AbstractSelectionControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Akregator27AbstractSelectionControllerE_t>.metaTypes,
    nullptr
} };

void Akregator::AbstractSelectionController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractSelectionController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentSubscriptionChanged((*reinterpret_cast<std::add_pointer_t<Akregator::TreeNode*>>(_a[1]))); break;
        case 1: _t->currentArticleChanged((*reinterpret_cast<std::add_pointer_t<Akregator::Article>>(_a[1]))); break;
        case 2: _t->articleDoubleClicked((*reinterpret_cast<std::add_pointer_t<Akregator::Article>>(_a[1]))); break;
        case 3: _t->settingsChanged(); break;
        case 4: _t->activitiesChanged(); break;
        case 5: _t->setFilters((*reinterpret_cast<std::add_pointer_t<std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher>>>>(_a[1]))); break;
        case 6: _t->forceFilterUpdate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractSelectionController::*)(Akregator::TreeNode * )>(_a, &AbstractSelectionController::currentSubscriptionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractSelectionController::*)(const Akregator::Article & )>(_a, &AbstractSelectionController::currentArticleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractSelectionController::*)(const Akregator::Article & )>(_a, &AbstractSelectionController::articleDoubleClicked, 2))
            return;
    }
}

const QMetaObject *Akregator::AbstractSelectionController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akregator::AbstractSelectionController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Akregator27AbstractSelectionControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Akregator::AbstractSelectionController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Akregator::AbstractSelectionController::currentSubscriptionChanged(Akregator::TreeNode * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akregator::AbstractSelectionController::currentArticleChanged(const Akregator::Article & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Akregator::AbstractSelectionController::articleDoubleClicked(const Akregator::Article & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
